/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db;

public class Catalog extends com.mysql.grt.base.NamedGrtObject {

    protected Catalog() {
    }

    public Catalog(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new CatalogDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new CatalogDataGlobal((String) obj);
        }
    }

    public String getDefaultCharacterSetName() {
        return ((CatalogData) data).getDefaultCharacterSetName();
    }

    public String setDefaultCharacterSetName(String defaultCharacterSetName) {
        ((CatalogData) data).setDefaultCharacterSetName(defaultCharacterSetName);

        return getDefaultCharacterSetName();
    }

    public String getDefaultCollationName() {
        return ((CatalogData) data).getDefaultCollationName();
    }

    public String setDefaultCollationName(String defaultCollationName) {
        ((CatalogData) data).setDefaultCollationName(defaultCollationName);

        return getDefaultCollationName();
    }

    public com.mysql.grt.db.Version getVersion() {
        return ((CatalogData) data).getVersion();
    }

    public com.mysql.grt.db.Version setVersion(com.mysql.grt.db.Version version) {
        ((CatalogData) data).setVersion(version);

        return getVersion();
    }

    public com.mysql.grt.GrtHashMap getCustomData() {
        return ((CatalogData) data).getCustomData();
    }

    public com.mysql.grt.GrtHashMap setCustomData(com.mysql.grt.GrtHashMap customData) {
        ((CatalogData) data).setCustomData(customData);

        return getCustomData();
    }

    public com.mysql.grt.db.SchemaList getSchemata() {
        return ((CatalogData) data).getSchemata();
    }

    public com.mysql.grt.db.SchemaList setSchemata(com.mysql.grt.db.SchemaList schemata) {
        ((CatalogData) data).setSchemata(schemata);

        return getSchemata();
    }

    public com.mysql.grt.db.SimpleDatatypeList getSimpleDatatypes() {
        return ((CatalogData) data).getSimpleDatatypes();
    }

    public com.mysql.grt.db.SimpleDatatypeList setSimpleDatatypes(com.mysql.grt.db.SimpleDatatypeList simpleDatatypes) {
        ((CatalogData) data).setSimpleDatatypes(simpleDatatypes);

        return getSimpleDatatypes();
    }

    public com.mysql.grt.db.CharacterSetList getCharacterSets() {
        return ((CatalogData) data).getCharacterSets();
    }

    public com.mysql.grt.db.CharacterSetList setCharacterSets(com.mysql.grt.db.CharacterSetList characterSets) {
        ((CatalogData) data).setCharacterSets(characterSets);

        return getCharacterSets();
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            if (getDefaultCharacterSetName() != null) {
                xml.append("<value type=\"string\" key=\"defaultCharacterSetName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDefaultCharacterSetName()) + "</value>\n");
            }

            if (getDefaultCollationName() != null) {
                xml.append("<value type=\"string\" key=\"defaultCollationName\">"
                        + com.mysql.grt.Grt.escapeStringForXml(getDefaultCollationName()) + "</value>\n");
            }

            if (getSchemata() != null) {
                getSchemata().getGrtXml(xml, " key=\"schemata\"");
            }

            if (getVersion() != null) {
                getVersion().getGrtXml(xml, " key=\"version\"");
            }

            if (getCustomData() != null) {
                getCustomData().getGrtXml(xml, " key=\"customData\"");
            }

            if (getSimpleDatatypes() != null) {
                getSimpleDatatypes().getGrtRefXml(xml, " key=\"simpleDatatypes\"");
            }

            if (getCharacterSets() != null) {
                getCharacterSets().getGrtRefXml(xml, " key=\"characterSets\"");
            }

        return xml;
    }
}
