/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db.migration;

public class MigrationDataLocal extends com.mysql.grt.GrtObjectDataLocal implements MigrationData {

    private com.mysql.grt.GrtStringList sourceSchemataNames;

    private com.mysql.grt.GrtStringList selectedSchemataNames;

    private com.mysql.grt.GrtStringList ignoreList;

    private com.mysql.grt.db.migration.MappingList mappingDefaults;

    private com.mysql.grt.db.migration.MappingList mappingDefinitions;

    private com.mysql.grt.base.ObjectLogList migrationLog;

    private com.mysql.grt.base.ObjectLogList creationLog;

    private com.mysql.grt.base.ObjectLogList dataTransferLog;

    private com.mysql.grt.db.migration.DatatypeMappingList genericDatatypeMappings;

    private com.mysql.grt.db.mgmt.Connection sourceConnection;

    private com.mysql.grt.db.mgmt.Connection targetConnection;

    private com.mysql.grt.db.Catalog sourceCatalog;

    private com.mysql.grt.db.Catalog targetCatalog;

    private com.mysql.grt.db.Version targetVersion;

    private com.mysql.grt.GrtStringHashMap objectCreationParams;

    private com.mysql.grt.GrtStringHashMap dataBulkTransferParams;

    private com.mysql.grt.GrtStringHashMap applicationData;

    private com.mysql.grt.db.migration.MethodList migrationMethods;

    private com.mysql.grt.GrtObjectList sourceObjects;

    public MigrationDataLocal(com.mysql.grt.GrtObject grtObject) {
        super(grtObject);
    }

    public com.mysql.grt.db.mgmt.Connection getSourceConnection() {
        if (sourceConnection == null)
            sourceConnection = new com.mysql.grt.db.mgmt.Connection(this.grtObject);
        return sourceConnection;
    }

    public com.mysql.grt.db.mgmt.Connection setSourceConnection(com.mysql.grt.db.mgmt.Connection sourceConnection) {
        this.sourceConnection = sourceConnection;

        return getSourceConnection();
    }

    public com.mysql.grt.db.mgmt.Connection getTargetConnection() {
        if (targetConnection == null)
            targetConnection = new com.mysql.grt.db.mgmt.Connection(this.grtObject);
        return targetConnection;
    }

    public com.mysql.grt.db.mgmt.Connection setTargetConnection(com.mysql.grt.db.mgmt.Connection targetConnection) {
        this.targetConnection = targetConnection;

        return getTargetConnection();
    }

    public com.mysql.grt.db.Catalog getSourceCatalog() {
        if (sourceCatalog == null)
            sourceCatalog = new com.mysql.grt.db.Catalog(this.grtObject);
        return sourceCatalog;
    }

    public com.mysql.grt.db.Catalog setSourceCatalog(com.mysql.grt.db.Catalog sourceCatalog) {
        this.sourceCatalog = sourceCatalog;

        return getSourceCatalog();
    }

    public com.mysql.grt.db.Catalog getTargetCatalog() {
        if (targetCatalog == null)
            targetCatalog = new com.mysql.grt.db.Catalog(this.grtObject);
        return targetCatalog;
    }

    public com.mysql.grt.db.Catalog setTargetCatalog(com.mysql.grt.db.Catalog targetCatalog) {
        this.targetCatalog = targetCatalog;

        return getTargetCatalog();
    }

    public com.mysql.grt.db.Version getTargetVersion() {
        if (targetVersion == null)
            targetVersion = new com.mysql.grt.db.Version(this.grtObject);
        return targetVersion;
    }

    public com.mysql.grt.db.Version setTargetVersion(com.mysql.grt.db.Version targetVersion) {
        this.targetVersion = targetVersion;

        return getTargetVersion();
    }

    public com.mysql.grt.GrtStringHashMap getObjectCreationParams() {
        if (objectCreationParams == null)
            objectCreationParams = new com.mysql.grt.GrtStringHashMap(this.grtObject);
        return objectCreationParams;
    }

    public com.mysql.grt.GrtStringHashMap setObjectCreationParams(com.mysql.grt.GrtStringHashMap objectCreationParams) {
        this.objectCreationParams = objectCreationParams;

        return getObjectCreationParams();
    }

    public com.mysql.grt.GrtStringHashMap getDataBulkTransferParams() {
        if (dataBulkTransferParams == null)
            dataBulkTransferParams = new com.mysql.grt.GrtStringHashMap(this.grtObject);
        return dataBulkTransferParams;
    }

    public com.mysql.grt.GrtStringHashMap setDataBulkTransferParams(com.mysql.grt.GrtStringHashMap dataBulkTransferParams) {
        this.dataBulkTransferParams = dataBulkTransferParams;

        return getDataBulkTransferParams();
    }

    public com.mysql.grt.GrtStringHashMap getApplicationData() {
        if (applicationData == null)
            applicationData = new com.mysql.grt.GrtStringHashMap(this.grtObject);
        return applicationData;
    }

    public com.mysql.grt.GrtStringHashMap setApplicationData(com.mysql.grt.GrtStringHashMap applicationData) {
        this.applicationData = applicationData;

        return getApplicationData();
    }

    public com.mysql.grt.GrtStringList getSourceSchemataNames() {
        if (sourceSchemataNames == null)
            sourceSchemataNames = new com.mysql.grt.GrtStringList(this.grtObject);
        return sourceSchemataNames;
    }

    public com.mysql.grt.GrtStringList setSourceSchemataNames(com.mysql.grt.GrtStringList sourceSchemataNames) {
        this.sourceSchemataNames = sourceSchemataNames;
        return getSourceSchemataNames();
    }

    public com.mysql.grt.GrtStringList getSelectedSchemataNames() {
        if (selectedSchemataNames == null)
            selectedSchemataNames = new com.mysql.grt.GrtStringList(this.grtObject);
        return selectedSchemataNames;
    }

    public com.mysql.grt.GrtStringList setSelectedSchemataNames(com.mysql.grt.GrtStringList selectedSchemataNames) {
        this.selectedSchemataNames = selectedSchemataNames;
        return getSelectedSchemataNames();
    }

    public com.mysql.grt.GrtStringList getIgnoreList() {
        if (ignoreList == null)
            ignoreList = new com.mysql.grt.GrtStringList(this.grtObject);
        return ignoreList;
    }

    public com.mysql.grt.GrtStringList setIgnoreList(com.mysql.grt.GrtStringList ignoreList) {
        this.ignoreList = ignoreList;
        return getIgnoreList();
    }

    public com.mysql.grt.db.migration.MappingList getMappingDefaults() {
        if (mappingDefaults == null)
            mappingDefaults = new com.mysql.grt.db.migration.MappingList(this.grtObject);
        return mappingDefaults;
    }

    public com.mysql.grt.db.migration.MappingList setMappingDefaults(com.mysql.grt.db.migration.MappingList mappingDefaults) {
        this.mappingDefaults = mappingDefaults;
        return getMappingDefaults();
    }

    public com.mysql.grt.db.migration.MappingList getMappingDefinitions() {
        if (mappingDefinitions == null)
            mappingDefinitions = new com.mysql.grt.db.migration.MappingList(this.grtObject);
        return mappingDefinitions;
    }

    public com.mysql.grt.db.migration.MappingList setMappingDefinitions(com.mysql.grt.db.migration.MappingList mappingDefinitions) {
        this.mappingDefinitions = mappingDefinitions;
        return getMappingDefinitions();
    }

    public com.mysql.grt.base.ObjectLogList getMigrationLog() {
        if (migrationLog == null)
            migrationLog = new com.mysql.grt.base.ObjectLogList(this.grtObject);
        return migrationLog;
    }

    public com.mysql.grt.base.ObjectLogList setMigrationLog(com.mysql.grt.base.ObjectLogList migrationLog) {
        this.migrationLog = migrationLog;
        return getMigrationLog();
    }

    public com.mysql.grt.base.ObjectLogList getCreationLog() {
        if (creationLog == null)
            creationLog = new com.mysql.grt.base.ObjectLogList(this.grtObject);
        return creationLog;
    }

    public com.mysql.grt.base.ObjectLogList setCreationLog(com.mysql.grt.base.ObjectLogList creationLog) {
        this.creationLog = creationLog;
        return getCreationLog();
    }

    public com.mysql.grt.base.ObjectLogList getDataTransferLog() {
        if (dataTransferLog == null)
            dataTransferLog = new com.mysql.grt.base.ObjectLogList(this.grtObject);
        return dataTransferLog;
    }

    public com.mysql.grt.base.ObjectLogList setDataTransferLog(com.mysql.grt.base.ObjectLogList dataTransferLog) {
        this.dataTransferLog = dataTransferLog;
        return getDataTransferLog();
    }

    public com.mysql.grt.db.migration.DatatypeMappingList getGenericDatatypeMappings() {
        if (genericDatatypeMappings == null)
            genericDatatypeMappings = new com.mysql.grt.db.migration.DatatypeMappingList(this.grtObject);
        return genericDatatypeMappings;
    }

    public com.mysql.grt.db.migration.DatatypeMappingList setGenericDatatypeMappings(com.mysql.grt.db.migration.DatatypeMappingList genericDatatypeMappings) {
        this.genericDatatypeMappings = genericDatatypeMappings;
        return getGenericDatatypeMappings();
    }

    public com.mysql.grt.db.migration.MethodList getMigrationMethods() {
        if (migrationMethods == null)
            migrationMethods = new com.mysql.grt.db.migration.MethodList(this.grtObject);
        return migrationMethods;
    }

    public com.mysql.grt.db.migration.MethodList setMigrationMethods(com.mysql.grt.db.migration.MethodList migrationMethods) {
        this.migrationMethods = migrationMethods;
        return getMigrationMethods();
    }

    public com.mysql.grt.GrtObjectList getSourceObjects() {
        if (sourceObjects == null)
            sourceObjects = new com.mysql.grt.GrtObjectList(this.grtObject);
        return sourceObjects;
    }

    public com.mysql.grt.GrtObjectList setSourceObjects(com.mysql.grt.GrtObjectList sourceObjects) {
        this.sourceObjects = sourceObjects;
        return getSourceObjects();
    }

}
